@@ -1,10 +1,7 @@
 haptable.haplinSlide <- function(object){
 
-
 .ut <- f.haptable.list(object)
-names(.ut)[names(.ut) == "stratum"] <- "window"
+names(.ut)[names(.ut) == "element"] <- "window"
 
 return(.ut)
-
-
 }
